﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Newtonsoft.Json.Linq;

namespace EDPlayerJournal.Entries; 
public class LocationEntry : Entry {
    public string? StarSystem { get; set; }
    public string? SystemFaction { get; set; }
    public string? StationName { get; set; }
    public ulong SystemAddress { get; set; }
    public string? Body { get; set; }
    public bool Docked { get; set; }
    public long[]? StarPos { get; set; }

    public List<Faction> SystemFactions { get; set; } = new List<Faction>();

    protected override void Initialise() {
        StarSystem = JSON.Value<string>("StarSystem") ?? "";
        SystemAddress = JSON.Value<ulong?>("SystemAddress") ?? 0;
        Docked = JSON.Value<bool?>("Docked") ?? false;
        StationName = JSON.Value<string>("StationName") ?? "";

        var pos = JSON.Value<JArray>("StarPos");
        if (pos != null) {
            StarPos = pos.ToObject<long[]>();
        }

        JObject? systemfaction = JSON.Value<JObject>("SystemFaction");
        if (systemfaction != null) {
            SystemFaction = systemfaction.Value<string>("Name") ?? "";
        }

        JArray? factions = JSON.Value<JArray>("Factions");
        if (factions != null) {
            foreach (JObject system_faction in factions) {
                Faction? f = Faction.FromJSON(system_faction);
                if (f != null) {
                    SystemFactions.Add(f);
                }
            }
        }
    }
}
